// $Ringlet: cs/misc/vcs-net/vcs-net/VCSAttribute.cs,v 1.2 2003/10/23 10:14:36 roam Exp $

using System;
using System.Text;

namespace Ringlet.Misc.VCS
{
	/// <summary>
	/// An attribute for storing VCS tag data represented as ASCII
	/// characters so that programs like CVS's ident tool pick it up.
	/// </summary>
	[AttributeUsage(AttributeTargets.All, Inherited = false,
	    AllowMultiple = true)]
	public class VCSAttribute : System.Attribute
	{
		/// <summary>
		/// The tag string.
		/// </summary>
		string tag;
		/// <summary>
		/// The ASCII representation of the tag string.
		/// </summary>
		byte[] asciitag;
		
		/// <summary>
		/// Create a VCS attribute with no tag defined.
		/// </summary>
		public VCSAttribute()
		{
			tag = null;
			asciitag = null;
		}
		
		/// <summary>
		/// Create a VCS attribute with a specified VCS tag.
		/// </summary>
		/// <param name="ntag">the VCS tag to use</param>
		public VCSAttribute(string ntag) : this()
		{
			Tag = ntag;
		}

		/// <summary>
		/// Get or set the VCS tag.
		/// </summary>
		public string Tag
		{
			get
			{
				return (tag);
			}

			set
			{
				ASCIIEncoding enc;
				
				tag = value;
				enc = new ASCIIEncoding();
				asciitag = enc.GetBytes(tag);
			}
		}
	}
}
